@@ -140,7 +140,7 @@ static void appendLanguagesFromVariable(QStringList &languages,
     }
 }
 
-#ifndef Q_OS_UNIX
+#if !defined(Q_OS_UNIX) || defined(Q_OS_ANDROID)
 static void appendLanguagesFromQLocale(QStringList &languages, const QLocale &locale)
 {
     const QStringList uiLangs = locale.uiLanguages();
@@ -198,6 +198,14 @@ class KLocalizedStringPrivate
     bool markupAware;
     bool relaxedSubs;
 
+    KLocalizedStringPrivate()
+       : format()
+       , numberSet(false)
+       , markupAware(false)
+       , relaxedSubs(false)
+    {
+    }
+
     static void translateRaw(const QByteArray &domain,
                              const QStringList &languages,
                              const QByteArray &msgctxt,
@@ -355,7 +363,7 @@ void KLocalizedStringPrivateStatics::initializeLocaleLanguages()
     appendLanguagesFromVariable(localeLanguages, "LC_ALL");
     appendLanguagesFromVariable(localeLanguages, "LC_MESSAGES");
     appendLanguagesFromVariable(localeLanguages, "LANG");
-#ifndef Q_OS_UNIX
+#if !defined(Q_OS_UNIX) || defined(Q_OS_ANDROID)
     // For non UNIX platforms the environment variables might not
     // suffice so we add system locale UI languages, too.
     appendLanguagesFromQLocale(localeLanguages, QLocale::system());
@@ -642,8 +650,8 @@ QString KLocalizedStringPrivate::toString(const QByteArray &domain,
     // Execute any scripted post calls; they cannot modify the final result,
     // but are used to set states.
     if (s->ktrs != nullptr) {
-        QStringList pcalls = s->ktrs->postCalls(language);
-        foreach (const QString &pcall, pcalls) {
+        const QStringList pcalls = s->ktrs->postCalls(language);
+        for (const QString &pcall : pcalls) {
             postTranscript(pcall, language, country, finalTranslation,
                            resolvedArguments, resolvedValues);
         }
@@ -1305,15 +1313,7 @@ bool KLocalizedString::isApplicationTranslatedInto(const QString &language)
 
 QSet<QString> KLocalizedString::availableApplicationTranslations()
 {
-    KLocalizedStringPrivateStatics *s = staticsKLSP();
-    QSet<QString> availableLanguages;
-    QByteArray domain = s->applicationDomain;
-    if (!domain.isEmpty()) {
-        availableLanguages = KCatalog::availableCatalogLanguages(domain);
-        availableLanguages.insert(s->codeLanguage);
-    }
-
-    return availableLanguages;
+    return availableDomainTranslations(staticsKLSP()->applicationDomain);
 }
 
 QSet<QString> KLocalizedString::availableDomainTranslations(const QByteArray &domain)
